@@ -1,30 +1,15 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 _license_text = \
 """/*
-  This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2017 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
+    SPDX-FileContributor: Sérgio Martins <sergio.martins@kdab.com>
 
-  Copyright (C) 2017 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Author: Sérgio Martins <sergio.martins@kdab.com>
-
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 """
 
-import sys, os, json, argparse, datetime, io
+import sys, os, json, argparse, datetime, io, subprocess
 from shutil import copyfile
 
 CHECKS_FILENAME = 'checks.json'
@@ -77,10 +62,12 @@ def read_file(filename):
     f.close()
     return contents
 
-def write_file(filename, contents):
+def write_file(filename: str, contents):
     f = io.open(filename, 'w', newline='\n', encoding='utf8')
     f.write(contents)
     f.close()
+    if filename.endswith('.h') or filename.endswith('.cpp'):
+        subprocess.run(['clang-format', '-i', filename])
 
 def get_copyright():
     year = datetime.datetime.now().year
@@ -136,10 +123,6 @@ class Check:
     def readme_path(self):
         return docs_path() + self.readme_name()
 
-
-    def supportsQt4(self):
-        return self.minimum_qt_version < 50000
-
     def get_class_name(self):
         if self.class_name:
             return self.class_name
@@ -272,21 +255,18 @@ void CheckManager::registerChecks()
 """
 
     for c in checks:
-        qt4flag = "RegisteredCheck::Option_None"
-        if not c.supportsQt4():
-            qt4flag = "RegisteredCheck::Option_Qt4Incompatible"
-
+        qtflags = "RegisteredCheck::Option_None"
         if c.visits_stmts:
-            qt4flag += " | RegisteredCheck::Option_VisitsStmts"
+            qtflags += " | RegisteredCheck::Option_VisitsStmts"
         if c.visits_decls:
-            qt4flag += " | RegisteredCheck::Option_VisitsDecls"
+            qtflags += " | RegisteredCheck::Option_VisitsDecls"
 
-        qt4flag = qt4flag.replace("RegisteredCheck::Option_None |", "")
+        qtflags = qtflags.replace("RegisteredCheck::Option_None |", "")
 
         if c.ifndef:
             text += "#ifndef " + c.ifndef + "\n"
 
-        text += '    registerCheck(check<%s>("%s", %s, %s));\n' % (c.get_class_name(), c.name, level_num_to_enum(c.level), qt4flag)
+        text += '    registerCheck(check<%s>("%s", %s, %s));\n' % (c.get_class_name(), c.name, level_num_to_enum(c.level), qtflags)
 
         fixitID = 1
         for fixit in c.fixits:
@@ -301,8 +281,8 @@ void CheckManager::registerChecks()
     comment_text = \
 """
 /**
- * To add a new check you can either edit this file, or use the python script:
- * dev-scripts/generate.py > src/Checks.h
+ * New scripts should be added to the check.json file and the files should be regenerated
+ * ./dev-scripts/generate.py --generate
  */
 """
     text = _license_text + '\n' + comment_text + '\n' + text
@@ -316,14 +296,14 @@ void CheckManager::registerChecks()
     return False
 #-------------------------------------------------------------------------------
 def generate_cmake_file(checks):
-    text = "set(CLAZY_CHECKS_SRCS ${CLAZY_CHECKS_SRCS}\n"
+    text = "# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n\nset(CLAZY_CHECKS_SRCS ${CLAZY_CHECKS_SRCS}\n"
     for level in [-1, 0, 1, 2, 3]:
         for check in checks:
             if check.level == level:
                 text += "  ${CMAKE_CURRENT_LIST_DIR}/src/" + check.qualified_cpp_filename() + "\n"
     text += ")\n"
 
-    filename = clazy_source_path() + "CheckSources.cmake"
+    filename = clazy_source_path() + "CheckSources.generated.cmake"
     old_text = read_file(filename)
     if old_text != text:
         write_file(filename, text)
@@ -483,11 +463,22 @@ def generate_readme(checks):
 #-------------------------------------------------------------------------------
 def generate_ctest(checks):
     # Generates the ClazyTests.cmake file
-    filename = clazy_source_path() + 'ClazyTests.cmake'
+    filename = clazy_source_path() + 'ClazyTests.generated.cmake'
 
-    contents = "# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n\n"
+    contents = """# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n
+macro(add_clazy_test name)
+  add_test(NAME ${name} COMMAND python3 run_tests.py ${name} --verbose WORKING_DIRECTORY ${CMAKE_SOURCE_DIR}/tests/)
+  set_property(TEST ${name} PROPERTY
+    ENVIRONMENT "CLAZYPLUGIN_CXX=$<TARGET_FILE:ClazyPlugin>;CLAZYSTANDALONE_CXX=$<TARGET_FILE:clazy-standalone>;$<$<BOOL:${HAS_STD_FILESYSTEM}>:CLAZY_HAS_FILESYSTEM=>"
+  )
+endmacro()\n
+"""
     for c in checks:
-        contents += 'add_test(NAME %s COMMAND python3 run_tests.py %s WORKING_DIRECTORY ${CMAKE_SOURCE_DIR}/tests/)\n' % (c.name, c.name)
+        contents += 'add_clazy_test(%s)\n' % (c.name)
+
+
+    contents += 'add_clazy_test(clazy-standalone)\n'
+    contents += 'add_clazy_test(clazy)\n'
 
     f = io.open(filename, 'w', newline='\n', encoding='utf8')
     f.write(contents)
