@@ -1,49 +1,36 @@
 /*
-    This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2015 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
+    SPDX-FileContributor: Sérgio Martins <sergio.martins@kdab.com>
 
-    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-    Author: Sérgio Martins <sergio.martins@kdab.com>
+    SPDX-FileCopyrightText: 2015-2017 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2015-2017 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef CLAZY_AST_ACTION_H
 #define CLAZY_AST_ACTION_H
 
-#include "checkmanager.h"
 #include "ClazyContext.h"
 #include "checkbase.h"
+#include "checkmanager.h"
 
 #include <clang/AST/ASTConsumer.h>
-#include <clang/Frontend/FrontendAction.h>
 #include <clang/AST/RecursiveASTVisitor.h>
+#include <clang/Frontend/FrontendAction.h>
 #include <llvm/ADT/StringRef.h>
 
 #include <memory>
-#include <vector>
 #include <string>
 #include <utility>
+#include <vector>
 
-namespace llvm {
+namespace llvm
+{
 class raw_ostream;
-}  // namespace llvm
+} // namespace llvm
 
-namespace clang {
+namespace clang
+{
 class CompilerInstance;
 class ASTContext;
 class Decl;
@@ -53,8 +40,7 @@ class Stmt;
 /**
  * This is the FrontendAction that is run when clazy is used as a clang plugin.
  */
-class ClazyASTAction
-    : public clang::PluginASTAction
+class ClazyASTAction : public clang::PluginASTAction
 {
 public:
     ClazyASTAction();
@@ -67,6 +53,7 @@ protected:
 
     void PrintHelp(llvm::raw_ostream &ros) const;
     void PrintAnchorHeader(llvm::raw_ostream &ro, RegisteredCheck::List &checks) const;
+
 private:
     void printRequestedChecks() const;
     RegisteredCheck::List m_checks;
@@ -78,8 +65,7 @@ private:
 /**
  * This is the FrontendAction that is run when clazy is invoked via clazy-standalone.
  */
-class ClazyStandaloneASTAction
-    : public clang::ASTFrontendAction
+class ClazyStandaloneASTAction : public clang::ASTFrontendAction
 {
 public:
     explicit ClazyStandaloneASTAction(const std::string &checkList,
@@ -88,8 +74,10 @@ public:
                                       const std::string &exportFixesFilename,
                                       const std::vector<std::string> &translationUnitPaths,
                                       ClazyContext::ClazyOptions = ClazyContext::ClazyOption_None);
+
 protected:
     std::unique_ptr<clang::ASTConsumer> CreateASTConsumer(clang::CompilerInstance &ci, llvm::StringRef) override;
+
 private:
     const std::string m_checkList;
     const std::string m_headerFilter;
@@ -102,27 +90,31 @@ private:
 /**
  * Clazy's AST Consumer.
  */
-class ClazyASTConsumer
-    : public clang::ASTConsumer
-    , public clang::RecursiveASTVisitor<ClazyASTConsumer>
+class ClazyASTConsumer : public clang::ASTConsumer, public clang::RecursiveASTVisitor<ClazyASTConsumer>
 {
 public:
     explicit ClazyASTConsumer(ClazyContext *context);
     ~ClazyASTConsumer() override;
-    bool shouldVisitImplicitCode() const { return m_context->isVisitImplicitCode(); }
+    bool shouldVisitImplicitCode() const
+    {
+        return m_context->isVisitImplicitCode();
+    }
 
     bool VisitDecl(clang::Decl *decl);
     bool VisitStmt(clang::Stmt *stm);
     void HandleTranslationUnit(clang::ASTContext &ctx) override;
     void addCheck(const std::pair<CheckBase *, RegisteredCheck> &check);
 
-    ClazyContext *context() const { return m_context; }
+    ClazyContext *context() const
+    {
+        return m_context;
+    }
 
 private:
     ClazyASTConsumer(const ClazyASTConsumer &) = delete;
     clang::Stmt *lastStm = nullptr;
     ClazyContext *const m_context;
-    //CheckBase::List m_createdChecks;
+    // CheckBase::List m_createdChecks;
     CheckBase::List m_checksToVisitStmts;
     CheckBase::List m_checksToVisitDecls;
 #ifndef CLAZY_DISABLE_AST_MATCHERS
