@@ -1,22 +1,7 @@
 /*
-    This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2017 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef CLAZY_PREPROCESSOR_VISITOR_H
@@ -36,7 +21,8 @@
 #include <unordered_map>
 #include <vector>
 
-namespace clang {
+namespace clang
+{
 class CompilerInstance;
 class SourceManager;
 class SourceRange;
@@ -48,39 +34,51 @@ class SourceLocation;
 
 using uint = unsigned;
 
-class PreProcessorVisitor
-    : public clang::PPCallbacks
+class PreProcessorVisitor : public clang::PPCallbacks
 {
     PreProcessorVisitor(const PreProcessorVisitor &) = delete;
+
 public:
     explicit PreProcessorVisitor(const clang::CompilerInstance &ci);
 
     // Returns for example 050601 (Qt 5.6.1), or -1 if we don't know the version
-    int qtVersion() const { return m_qtVersion; }
+    int qtVersion() const
+    {
+        return m_qtVersion;
+    }
 
     bool isBetweenQtNamespaceMacros(clang::SourceLocation loc);
 
     // Returns true if QT_NO_KEYWORDS is defined
-    bool isQT_NO_KEYWORDS() const { return m_isQtNoKeywords; }
+    bool isQT_NO_KEYWORDS() const
+    {
+        return m_isQtNoKeywords;
+    }
 
-    bool hasInclude(const std::string& fileName, bool IsAngled) const;
+    bool hasInclude(const std::string &fileName, bool IsAngled) const;
     clang::SourceLocation endOfIncludeSection() const;
 
 protected:
-    void MacroExpands(const clang::Token &MacroNameTok, const clang::MacroDefinition &,
-                      clang::SourceRange range, const clang::MacroArgs *) override;
-    void InclusionDirective (clang::SourceLocation HashLoc, const clang::Token &IncludeTok,
-                             clang::StringRef FileName, bool IsAngled, clang::CharSourceRange FilenameRange,
-                             const clang::FileEntry *File, clang::StringRef SearchPath, clang::StringRef RelativePath,
-                             const clang::Module *Imported, clang::SrcMgr::CharacteristicKind FileType) override;
+    void MacroExpands(const clang::Token &MacroNameTok, const clang::MacroDefinition &, clang::SourceRange range, const clang::MacroArgs *) override;
+    void InclusionDirective(clang::SourceLocation HashLoc,
+                            const clang::Token &IncludeTok,
+                            clang::StringRef FileName,
+                            bool IsAngled,
+                            clang::CharSourceRange FilenameRange,
+                            clazy::OptionalFileEntryRef File,
+                            clang::StringRef SearchPath,
+                            clang::StringRef RelativePath,
+                            const clang::Module *Imported,
+                            clang::SrcMgr::CharacteristicKind FileType) override;
+
 private:
     std::string getTokenSpelling(const clang::MacroDefinition &) const;
     void updateQtVersion();
     void handleQtNamespaceMacro(clang::SourceLocation loc, clang::StringRef name);
 
     const clang::CompilerInstance &m_ci;
-    int m_qtMajorVersion  = -1;
-    int m_qtMinorVersion  = -1;
+    int m_qtMajorVersion = -1;
+    int m_qtMinorVersion = -1;
     int m_qtPatchVersion = -1;
     int m_qtVersion = -1;
     bool m_isQtNoKeywords = false;
