@@ -1,46 +1,29 @@
 /*
-    This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2015 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
+    SPDX-FileContributor: Sérgio Martins <sergio.martins@kdab.com>
 
-    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-    Author: Sérgio Martins <sergio.martins@kdab.com>
+    SPDX-FileCopyrightText: 2015 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "checkmanager.h"
-#include "clazy_stl.h"
-#include "ClazyContext.h"
 #include "Checks.h"
+#include "ClazyContext.h"
+#include "clazy_stl.h"
 
 #include <llvm/Support/raw_ostream.h>
 
-#include <stdlib.h>
-#include <assert.h>
-#include <string.h>
 #include <algorithm>
+#include <assert.h>
 #include <iterator>
-#include <memory>
+#include <stdlib.h>
+#include <string.h>
 
 using namespace clang;
-using namespace std;
 
-static const char * s_fixitNamePrefix = "fix-";
-static const char * s_levelPrefix = "level";
+static const char *s_fixitNamePrefix = "fix-";
+static const char *s_levelPrefix = "level";
 
 std::mutex CheckManager::m_lock;
 
@@ -50,7 +33,7 @@ CheckManager::CheckManager()
     registerChecks();
 }
 
-bool CheckManager::checkExists(const string &name) const
+bool CheckManager::checkExists(const std::string &name) const
 {
     return checkForName(m_registeredChecks, name) != m_registeredChecks.cend();
 }
@@ -66,7 +49,7 @@ void CheckManager::registerCheck(const RegisteredCheck &check)
     m_registeredChecks.push_back(check);
 }
 
-void CheckManager::registerFixIt(int id, const string &fixitName, const string &checkName)
+void CheckManager::registerFixIt(int id, const std::string &fixitName, const std::string &checkName)
 {
     if (!clazy::startsWith(fixitName, s_fixitNamePrefix)) {
         assert(false);
@@ -74,7 +57,7 @@ void CheckManager::registerFixIt(int id, const string &fixitName, const string &
     }
 
     auto &fixits = m_fixitsByCheckName[checkName];
-    for (const auto& fixit : fixits) {
+    for (const auto &fixit : fixits) {
         if (fixit.name == fixitName) {
             // It can't exist
             assert(false);
@@ -86,9 +69,9 @@ void CheckManager::registerFixIt(int id, const string &fixitName, const string &
     m_fixitByName.insert({fixitName, fixit});
 }
 
-CheckBase* CheckManager::createCheck(const string &name, ClazyContext *context)
+CheckBase *CheckManager::createCheck(const std::string &name, ClazyContext *context)
 {
-    for (const auto& rc : m_registeredChecks) {
+    for (const auto &rc : m_registeredChecks) {
         if (rc.name == name) {
             return rc.factory(context);
         }
@@ -98,18 +81,20 @@ CheckBase* CheckManager::createCheck(const string &name, ClazyContext *context)
     return nullptr;
 }
 
-string CheckManager::checkNameForFixIt(const string &fixitName) const
+std::string CheckManager::checkNameForFixIt(const std::string &fixitName) const
 {
-    if (fixitName.empty())
+    if (fixitName.empty()) {
         return {};
+    }
 
-    for (auto &registeredCheck : m_registeredChecks) {
+    for (const auto &registeredCheck : m_registeredChecks) {
         auto it = m_fixitsByCheckName.find(registeredCheck.name);
         if (it != m_fixitsByCheckName.end()) {
-            auto &fixits = (*it).second;
+            const auto &fixits = (*it).second;
             for (const RegisteredFixIt &fixit : fixits) {
-                if (fixit.name == fixitName)
+                if (fixit.name == fixitName) {
                     return (*it).first;
+                }
             }
         }
     }
@@ -121,46 +106,47 @@ RegisteredCheck::List CheckManager::availableChecks(CheckLevel maxLevel) const
 {
     RegisteredCheck::List checks = m_registeredChecks;
 
-    checks.erase(remove_if(checks.begin(), checks.end(),
-                           [maxLevel](const RegisteredCheck &r) { return r.level > maxLevel; }), checks.end());
-
+    checks.erase(remove_if(checks.begin(),
+                           checks.end(),
+                           [maxLevel](const RegisteredCheck &r) {
+                               return r.level > maxLevel;
+                           }),
+                 checks.end());
 
     return checks;
 }
 
-RegisteredCheck::List CheckManager::requestedChecksThroughEnv(vector<string> &userDisabledChecks) const
+RegisteredCheck::List CheckManager::requestedChecksThroughEnv(std::vector<std::string> &userDisabledChecks) const
 {
     static RegisteredCheck::List requestedChecksThroughEnv;
-    static vector<string> disabledChecksThroughEnv;
+    static std::vector<std::string> disabledChecksThroughEnv;
     if (requestedChecksThroughEnv.empty()) {
         const char *checksEnv = getenv("CLAZY_CHECKS");
         if (checksEnv) {
-            const string checksEnvStr = clazy::unquoteString(checksEnv);
-            requestedChecksThroughEnv = checksEnvStr == "all_checks" ? availableChecks(CheckLevel2)
-                                                                     : checksForCommaSeparatedString(checksEnvStr, /*by-ref=*/ disabledChecksThroughEnv);
+            const std::string checksEnvStr = clazy::unquoteString(checksEnv);
+            requestedChecksThroughEnv =
+                checksEnvStr == "all_checks" ? availableChecks(CheckLevel2) : checksForCommaSeparatedString(checksEnvStr, /*by-ref=*/disabledChecksThroughEnv);
         }
     }
 
-    std::copy(disabledChecksThroughEnv.begin(), disabledChecksThroughEnv.end(),
-              std::back_inserter(userDisabledChecks));
+    std::copy(disabledChecksThroughEnv.begin(), disabledChecksThroughEnv.end(), std::back_inserter(userDisabledChecks));
     return requestedChecksThroughEnv;
 }
 
-RegisteredCheck::List::const_iterator CheckManager::checkForName(const RegisteredCheck::List &checks,
-                                                                 const string &name) const
+RegisteredCheck::List::const_iterator CheckManager::checkForName(const RegisteredCheck::List &checks, const std::string &name) const
 {
     return clazy::find_if(checks, [name](const RegisteredCheck &r) {
         return r.name == name;
-    } );
+    });
 }
 
-RegisteredFixIt::List CheckManager::availableFixIts(const string &checkName) const
+RegisteredFixIt::List CheckManager::availableFixIts(const std::string &checkName) const
 {
     auto it = m_fixitsByCheckName.find(checkName);
     return it == m_fixitsByCheckName.end() ? RegisteredFixIt::List() : (*it).second;
 }
 
-static bool takeArgument(const string &arg, vector<string> &args)
+static bool takeArgument(const std::string &arg, std::vector<std::string> &args)
 {
     auto it = clazy::find(args, arg);
     if (it != args.end()) {
@@ -171,12 +157,12 @@ static bool takeArgument(const string &arg, vector<string> &args)
     return false;
 }
 
-RegisteredCheck::List CheckManager::requestedChecks(std::vector<std::string> &args, bool qt4Compat)
+RegisteredCheck::List CheckManager::requestedChecks(std::vector<std::string> &args)
 {
     RegisteredCheck::List result;
 
     // #1 Check if a level was specified
-    static const vector<string> levels = { "level0", "level1", "level2" };
+    static const std::vector<std::string> levels = {"level0", "level1", "level2"};
     const int numLevels = levels.size();
     CheckLevel requestedLevel = CheckLevelUndefined;
     for (int i = 0; i < numLevels; ++i) {
@@ -186,19 +172,20 @@ RegisteredCheck::List CheckManager::requestedChecks(std::vector<std::string> &ar
         }
     }
 
-    if (args.size() > 1) // we only expect a level and a comma separated list of arguments
+    if (args.size() > 1) { // we only expect a level and a comma separated list of arguments
         return {};
+    }
 
+    std::vector<std::string> userDisabledChecks;
     if (args.size() == 1) {
         // #2 Process list of comma separated checks that were passed to compiler
-        result = checksForCommaSeparatedString(args[0]);
-        if (result.empty()) // User passed inexisting checks.
+        result = checksForCommaSeparatedString(args[0], /*by-ref*/ userDisabledChecks);
+        if (result.empty() && userDisabledChecks.empty()) { // User passed inexisting checks.
             return {};
+        }
     }
 
     // #3 Append checks specified from env variable
-
-    vector<string> userDisabledChecks;
     RegisteredCheck::List checksFromEnv = requestedChecksThroughEnv(/*by-ref*/ userDisabledChecks);
     copy(checksFromEnv.cbegin(), checksFromEnv.cend(), back_inserter(result));
 
@@ -213,13 +200,6 @@ RegisteredCheck::List CheckManager::requestedChecks(std::vector<std::string> &ar
     clazy::sort_and_remove_dups(result, checkLessThan);
     CheckManager::removeChecksFromList(result, userDisabledChecks);
 
-    if (qt4Compat) {
-        // #5 Remove Qt4 incompatible checks
-        result.erase(remove_if(result.begin(), result.end(), [](const RegisteredCheck &c){
-            return c.options & RegisteredCheck::Option_Qt4Incompatible;
-        }), result.end());
-    }
-
     return result;
 }
 
@@ -235,50 +215,52 @@ RegisteredCheck::List CheckManager::checksForLevel(int level) const
     return result;
 }
 
-std::vector<std::pair<CheckBase*, RegisteredCheck>> CheckManager::createChecks(const RegisteredCheck::List &requestedChecks,
-                                                                               ClazyContext *context)
+std::vector<std::pair<CheckBase *, RegisteredCheck>> CheckManager::createChecks(const RegisteredCheck::List &requestedChecks, ClazyContext *context)
 {
     assert(context);
 
-    std::vector<std::pair<CheckBase*, RegisteredCheck>> checks;
+    std::vector<std::pair<CheckBase *, RegisteredCheck>> checks;
     checks.reserve(requestedChecks.size() + 1);
-    for (const auto& check : requestedChecks) {
-        checks.push_back({createCheck(check.name, context), check });
+    for (const auto &check : requestedChecks) {
+        checks.push_back({createCheck(check.name, context), check});
     }
 
     return checks;
 }
 
 /*static */
-void CheckManager::removeChecksFromList(RegisteredCheck::List &list, vector<string> &checkNames)
+void CheckManager::removeChecksFromList(RegisteredCheck::List &list, std::vector<std::string> &checkNames)
 {
     for (auto &name : checkNames) {
-        list.erase(remove_if(list.begin(), list.end(), [name](const RegisteredCheck &c) {
-            return c.name == name;
-        }), list.end());
+        list.erase(remove_if(list.begin(),
+                             list.end(),
+                             [name](const RegisteredCheck &c) {
+                                 return c.name == name;
+                             }),
+                   list.end());
     }
 }
 
-RegisteredCheck::List CheckManager::checksForCommaSeparatedString(const string &str) const
+RegisteredCheck::List CheckManager::checksForCommaSeparatedString(const std::string &str) const
 {
-    vector<string> byRefDummy;
+    std::vector<std::string> byRefDummy;
     return checksForCommaSeparatedString(str, byRefDummy);
 }
 
-RegisteredCheck::List CheckManager::checksForCommaSeparatedString(const string &str,
-                                                                  vector<string> &userDisabledChecks) const
+RegisteredCheck::List CheckManager::checksForCommaSeparatedString(const std::string &str, std::vector<std::string> &userDisabledChecks) const
 {
-    vector<string> checkNames = clazy::splitString(str, ',');
+    std::vector<std::string> checkNames = clazy::splitString(str, ',');
     RegisteredCheck::List result;
 
-    for (const string &name : checkNames) {
-        if (checkForName(result, name) != result.cend())
+    for (const std::string &name : checkNames) {
+        if (checkForName(result, name) != result.cend()) {
             continue; // Already added. Duplicate check specified. continue.
+        }
 
         auto it = checkForName(m_registeredChecks, name);
         if (it == m_registeredChecks.cend()) {
             // Unknown, but might be a fixit name
-            const string checkName = checkNameForFixIt(name);
+            const std::string checkName = checkNameForFixIt(name);
             auto it = checkForName(m_registeredChecks, checkName);
             const bool checkDoesntExist = it == m_registeredChecks.cend();
             if (checkDoesntExist) {
@@ -293,7 +275,7 @@ RegisteredCheck::List CheckManager::checksForCommaSeparatedString(const string &
                     }
                 } else {
                     if (clazy::startsWith(name, "no-")) {
-                        string checkName = name;
+                        std::string checkName = name;
                         checkName.erase(0, 3);
                         if (checkExists(checkName)) {
                             userDisabledChecks.push_back(checkName);
@@ -308,9 +290,8 @@ RegisteredCheck::List CheckManager::checksForCommaSeparatedString(const string &
                 result.push_back(*it);
             }
             continue;
-        } else {
-            result.push_back(*it);
         }
+        result.push_back(*it);
     }
 
     removeChecksFromList(result, userDisabledChecks);
@@ -318,27 +299,26 @@ RegisteredCheck::List CheckManager::checksForCommaSeparatedString(const string &
     return result;
 }
 
-vector<string> CheckManager::checksAsErrors() const
+std::vector<std::string> CheckManager::checksAsErrors() const
 {
-    auto checksAsErrosEnv = getenv("CLAZY_CHECKS_AS_ERRORS");
+    auto *checksAsErrosEnv = getenv("CLAZY_CHECKS_AS_ERRORS");
 
     if (checksAsErrosEnv) {
         auto checkNames = clazy::splitString(checksAsErrosEnv, ',');
-        vector<string> result;
+        std::vector<std::string> result;
 
         // Check whether all supplied check names are valid
-        for (const string &name : checkNames) {
-            auto it = clazy::find_if(m_registeredChecks, [&name](const RegisteredCheck &check)
-            {
+        for (const std::string &name : checkNames) {
+            auto it = clazy::find_if(m_registeredChecks, [&name](const RegisteredCheck &check) {
                 return check.name == name;
             });
-            if (it == m_registeredChecks.end())
+            if (it == m_registeredChecks.end()) {
                 llvm::errs() << "Invalid check: " << name << '\n';
-            else
+            } else {
                 result.emplace_back(name);
+            }
         }
         return result;
     }
-    else
-        return {};
+    return {};
 }
