@@ -1,29 +1,14 @@
 /*
-  This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2017 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "const-signal-or-slot.h"
+#include "AccessSpecifierManager.h"
+#include "ClazyContext.h"
 #include "QtUtils.h"
 #include "TypeUtils.h"
-#include "ClazyContext.h"
-#include "AccessSpecifierManager.h"
 
 #include <clang/AST/DeclCXX.h>
 #include <clang/AST/Expr.h>
@@ -32,14 +17,13 @@
 #include <clang/Basic/LLVM.h>
 #include <llvm/Support/Casting.h>
 
-namespace clang {
+namespace clang
+{
 class Decl;
 class FunctionDecl;
-}  // namespace clang
+} // namespace clang
 
 using namespace clang;
-using namespace std;
-
 
 ConstSignalOrSlot::ConstSignalOrSlot(const std::string &name, ClazyContext *context)
     : CheckBase(name, context, Option_CanIgnoreIncludes)
@@ -49,23 +33,26 @@ ConstSignalOrSlot::ConstSignalOrSlot(const std::string &name, ClazyContext *cont
 
 void ConstSignalOrSlot::VisitStmt(clang::Stmt *stmt)
 {
-    auto call = dyn_cast<CallExpr>(stmt);
+    auto *call = dyn_cast<CallExpr>(stmt);
     AccessSpecifierManager *accessSpecifierManager = m_context->accessSpecifierManager;
-    if (!call || !accessSpecifierManager)
+    if (!call || !accessSpecifierManager) {
         return;
+    }
 
     FunctionDecl *func = call->getDirectCallee();
-    if (!clazy::isConnect(func) || !clazy::connectHasPMFStyle(func))
+    if (!clazy::isConnect(func) || !clazy::connectHasPMFStyle(func)) {
         return;
+    }
 
-    CXXMethodDecl *slot =  clazy::receiverMethodForConnect(call);
-    if (!slot || !slot->isConst() || slot->getReturnType()->isVoidType()) // const and returning void must do something, so not a getter
+    CXXMethodDecl *slot = clazy::receiverMethodForConnect(call);
+    if (!slot || !slot->isConst() || slot->getReturnType()->isVoidType()) { // const and returning void must do something, so not a getter
         return;
+    }
 
     QtAccessSpecifierType specifierType = accessSpecifierManager->qtAccessSpecifierType(slot);
-    if (specifierType == QtAccessSpecifier_Slot || specifierType == QtAccessSpecifier_Signal)
+    if (specifierType == QtAccessSpecifier_Slot || specifierType == QtAccessSpecifier_Signal) {
         return; // For stuff explicitly marked as slots or signals we use VisitDecl
-
+    }
 
     // Here the user is connecting to a const method, which isn't marked as slot or signal and returns non-void
     // Looks like a getter!
@@ -75,31 +62,37 @@ void ConstSignalOrSlot::VisitStmt(clang::Stmt *stmt)
 
 void ConstSignalOrSlot::VisitDecl(Decl *decl)
 {
-    auto method = dyn_cast<CXXMethodDecl>(decl);
-    if (!method || !method->isConst())
+    auto *method = dyn_cast<CXXMethodDecl>(decl);
+    if (!method || !method->isConst()) {
         return;
+    }
 
     AccessSpecifierManager *a = m_context->accessSpecifierManager;
-    if (!a)
+    if (!a) {
         return;
+    }
 
-    if (method->isThisDeclarationADefinition() && !method->hasInlineBody()) // Don't warn twice
+    if (method->isThisDeclarationADefinition() && !method->hasInlineBody()) { // Don't warn twice
         return;
+    }
 
     CXXRecordDecl *record = method->getParent();
-    if (clazy::derivesFrom(record, "QDBusAbstractInterface"))
+    if (clazy::derivesFrom(record, "QDBusAbstractInterface")) {
         return;
+    }
 
     QtAccessSpecifierType specifierType = a->qtAccessSpecifierType(method);
 
     const bool isSlot = specifierType == QtAccessSpecifier_Slot;
     const bool isSignal = specifierType == QtAccessSpecifier_Signal;
 
-    if (!isSlot && !isSignal)
+    if (!isSlot && !isSignal) {
         return;
+    }
 
-    if (a->isScriptable(method))
+    if (a->isScriptable(method)) {
         return;
+    }
 
     if (isSlot && !method->getReturnType()->isVoidType()) {
         emitWarning(decl, "getter " + method->getQualifiedNameAsString() + " possibly mismarked as a slot");
