@@ -1,22 +1,7 @@
 /*
-  This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2017 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2017 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "qproperty-without-notify.h"
@@ -31,13 +16,12 @@
 #include <vector>
 
 class ClazyContext;
-namespace clang {
+namespace clang
+{
 class MacroInfo;
-}  // namespace clang
+} // namespace clang
 
 using namespace clang;
-using namespace std;
-
 
 QPropertyWithoutNotify::QPropertyWithoutNotify(const std::string &name, ClazyContext *context)
     : CheckBase(name, context, Option_CanIgnoreIncludes)
@@ -48,8 +32,9 @@ QPropertyWithoutNotify::QPropertyWithoutNotify(const std::string &name, ClazyCon
 void QPropertyWithoutNotify::VisitMacroExpands(const clang::Token &MacroNameTok, const clang::SourceRange &range, const MacroInfo *)
 {
     IdentifierInfo *ii = MacroNameTok.getIdentifierInfo();
-    if (!ii)
+    if (!ii) {
         return;
+    }
 
     if (ii->getName() == "Q_GADGET") {
         m_lastIsGadget = true;
@@ -62,24 +47,34 @@ void QPropertyWithoutNotify::VisitMacroExpands(const clang::Token &MacroNameTok,
     }
 
     // Gadgets can't have NOTIFY
-    if (m_lastIsGadget || ii->getName() != "Q_PROPERTY")
+    if (m_lastIsGadget || ii->getName() != "Q_PROPERTY") {
         return;
+    }
 
-    if (sm().isInSystemHeader(range.getBegin()))
+    if (sm().isInSystemHeader(range.getBegin())) {
         return;
+    }
     CharSourceRange crange = Lexer::getAsCharRange(range, sm(), lo());
 
-    string text = static_cast<std::string>(Lexer::getSourceText(crange, sm(), lo()));
-    if (text.back() == ')')
-        text.pop_back();
+    std::string text = static_cast<std::string>(Lexer::getSourceText(crange, sm(), lo()));
+    if (text.empty()) {
+        // If the text is empty, it is more likely there is an error
+        // in parsing than an empty Q_PROPERTY macro call (which would
+        // be a moc error anyhow).
+        return;
+    }
 
-    vector<string> split = clazy::splitString(text, ' ');
+    if (text.back() == ')') {
+        text.pop_back();
+    }
+
+    std::vector<std::string> split = clazy::splitString(text, ' ');
 
     bool found_read = false;
     bool found_constant = false;
     bool found_notify = false;
     for (std::string &token : split) {
-        clazy::rtrim(/*by-ref*/token);
+        clazy::rtrim(/*by-ref*/ token);
         if (!found_read && token == "READ") {
             found_read = true;
             continue;
@@ -96,9 +91,9 @@ void QPropertyWithoutNotify::VisitMacroExpands(const clang::Token &MacroNameTok,
         }
     }
 
-    if (!found_read || (found_notify || found_constant))
+    if (!found_read || (found_notify || found_constant)) {
         return;
-
+    }
 
     emitWarning(range.getBegin(), "Q_PROPERTY should have either NOTIFY or CONSTANT");
 }
