@@ -1,25 +1,10 @@
 /*
-    This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2015 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
+    SPDX-FileContributor: Sérgio Martins <sergio.martins@kdab.com>
 
-    Copyright (C) 2015 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-    Author: Sérgio Martins <sergio.martins@kdab.com>
+    SPDX-FileCopyrightText: 2015 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2015 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef FUNCTION_ARGS_BY_REF_H
@@ -31,7 +16,8 @@
 
 class ClazyContext;
 
-namespace clang {
+namespace clang
+{
 class Decl;
 class VarDecl;
 class FixItHint;
@@ -40,7 +26,8 @@ class FunctionDecl;
 class Stmt;
 }
 
-namespace clazy {
+namespace clazy
+{
 struct QualTypeClassification;
 }
 
@@ -48,13 +35,13 @@ struct QualTypeClassification;
  * Finds functions where big non-trivial types are passed by value instead of const-ref.
  * Looks into the body of the functions to see if the argument are read-only, it doesn't emit a warning otherwise.
  */
-class FunctionArgsByRef
-    : public CheckBase
+class FunctionArgsByRef : public CheckBase
 {
 public:
     FunctionArgsByRef(const std::string &name, ClazyContext *context);
     void VisitDecl(clang::Decl *decl) override;
     void VisitStmt(clang::Stmt *stmt) override;
+
 private:
     static bool shouldIgnoreClass(clang::CXXRecordDecl *);
     static bool shouldIgnoreOperator(clang::FunctionDecl *);
